# eric7.Plugins.VcsPlugins.vcsMercurial.QueuesExtension.HgQueuesHeaderDialog

Module implementing a dialog to show the commit message of the current patch.

### Global Attributes

None

### Classes

HgQueuesHeaderDialog | Class implementing a dialog to show the commit message of the current patch.

### Functions

None

## HgQueuesHeaderDialog

Class implementing a dialog to show the commit message of the current patch.

### Derived from

QDialog, Ui_HgQueuesHeaderDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgQueuesHeaderDialog | Constructor
__finish | Private slot called when the process finished or the user pressed the button.
__showError | Private slot to show some error.
__showOutput | Private slot to show some output.
closeEvent | Protected slot implementing a close event handler.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the list command.

### Static Methods

None

#### HgQueuesHeaderDialog (Constructor)

HgQueuesHeaderDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  reference to the parent widget (QWidget)

#### HgQueuesHeaderDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### HgQueuesHeaderDialog.__showError

__showError(out)

Private slot to show some error.

out
  error to be shown (string)

#### HgQueuesHeaderDialog.__showOutput

__showOutput(out)

Private slot to show some output.

out
  output to be shown (string)

#### HgQueuesHeaderDialog.closeEvent

closeEvent(e)

Protected slot implementing a close event handler.

e
  close event (QCloseEvent)

#### HgQueuesHeaderDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### HgQueuesHeaderDialog.start

start()

Public slot to start the list command.

Up